<?xml version="1.0" encoding="ISO-8859-1"?>

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

	<xsl:output method="html"/>

	<xsl:template match="/">
   		<html>
   			<head>
   				<meta http-equiv="Content-Type" content="text/html; charset=ISO-8859-1"/>
      			<title>SonarJ Report</title>
       			<link type="text/css" href="sonar.css" rel="stylesheet"/>
			    <style type="text/css" media="all">
			      @import url("maven-base.css");
			      @import url("maven-theme.css");
			      @import url("site.css");
			    </style>
   			</head>
   			<body>
                <table border="0">
                    <tr>
                        <td width="1%"><image src="sonar.gif"/></td><td><image src="spacer.gif" height="1"/><h1>SonarJ Project Report</h1></td>
                    </tr>
                    <tr>
                        <td><image src="spacer.gif" height="1"/></td>
                    </tr>
                    <tr>
                        <td colspan="2"><h2><xsl:value-of select="project/@name"/></h2></td>
                    </tr>
                    <tr>
                        <td colspan="2"><xsl:apply-templates/></td>
                    </tr>
                </table>
            </body>
		</html>
	</xsl:template>

  	<xsl:template match="project">
    	<h3>Report creation information</h3>
    	<table class="bodyTable">
 	      	<tr class="a">
	        	<td width="350">Creation date and time</td>
	        	<td><xsl:value-of select="@report-creation"/></td>
	      	</tr>
 	      	<tr class="a">
	        	<td width="350">SonarJ version</td>
	        	<td><xsl:value-of select="@sonarj-version"/></td>
	      	</tr>
 	      	<tr class="a">
	        	<td width="350">SonarJ licensee</td>
	        	<td><xsl:value-of select="@sonarj-licensee"/></td>
	      	</tr>
 	      	<tr class="a">
	        	<td width="350">SonarJ user</td>
	        	<td><xsl:value-of select="@sonarj-user"/></td>
	      	</tr>
 	      	<tr class="a">
	        	<td width="350">SonarJ expiration</td>
	        	<td><xsl:value-of select="@sonarj-expiration"/></td>
	      	</tr>
	      	<tr class="a">
	        	<td>Workspace file</td>
	        	<td><xsl:value-of select="@workspace-path"/></td>
	      	</tr>
	      	<tr class="a">
	        	<td>Workspace description</td>
	        	<td><xsl:value-of select="@workspace-description"/></td>
	      	</tr>
	      	<tr class="a">
	        	<td>Architecture file</td>
	        	<td><xsl:value-of select="@architecture-path"/></td>
	      	</tr>
	      	<tr class="a">
	        	<td>Architecture description</td>
	        	<td><xsl:value-of select="@architecture-description"/></td>
	      	</tr>
      	</table>

      	<xsl:choose>
	    	<xsl:when test="architecture-violations/@violating-type-relations + element-warnings/@warnings + assignment-report/@warnings + exclusion-report/@warnings > 0">
	    		<h3 class="colorRed">Problem count summary</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Problem count summary</h3>
	    	</xsl:otherwise>
		</xsl:choose>
        <table class="bodyTable">
            <tr class="a">
                <td width="350">Number of architecture violations</td>
                <td width="140" align="right"><xsl:value-of select="architecture-violations/@number"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of architecture-violating type relations</td>
                <td width="140" align="right"><xsl:value-of select="architecture-violations/@violating-type-relations"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of ignored architecture-violating type relations</td>
                <td width="140" align="right"><xsl:value-of select="architecture-violations/@ignored-violating-type-relations"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of element warnings (thereof cyclic)</td>
                <td width="140" align="right"><xsl:value-of select="element-warnings/@warnings"/> (<xsl:value-of select="count(element-warnings/warning[@name='Cyclic']/warning-element)"/>)</td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of ignored element warnings</td>
                <td width="140" align="right"><xsl:value-of select="element-warnings/@ignored"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of work items</td>
                <td width="140" align="right"><xsl:value-of select="work-items/@number"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of assignment warnings</td>
                <td width="140" align="right"><xsl:value-of select="assignment-report/@warnings"/></td>
                <td></td>
            </tr>
            <tr class="a">
                <td width="350">Number of exclusion warnings</td>
                <td width="140" align="right"><xsl:value-of select="exclusion-report/@warnings"/></td>
                <td></td>
            </tr>
        </table>

	    <xsl:apply-templates/>

	</xsl:template>

  	<xsl:template match="project/attributes">
    	<h3>Project attributes (<xsl:value-of select="@number"/>)</h3>
    	<xsl:if test="@number > 0">
	    	<table class="bodyTable">
			    <xsl:for-each select="attribute">
					<tr class="a">
				    	<td width="350"><xsl:value-of select="@name"/></td>
				        <td width="140" align="right"><xsl:value-of select="@value"/></td>
				        <td><xsl:value-of select="@description"/></td>
				    </tr>
			    </xsl:for-each>
	        </table>
        </xsl:if>
      </xsl:template>

    <xsl:template match="project/contained-elements">
    	<h3>Project elements</h3>
    	<table class="bodyTable">
		    <xsl:for-each select="number-of-elements">
		    	<xsl:sort select="@element" order="ascending"/>
				<tr class="a">
			    	<td width="350"><xsl:value-of select="@element"/></td>
			        <td width="140" align="right"><xsl:value-of select="@number"/></td>
			        <td></td>
			    </tr>
		    </xsl:for-each>
      	</table>
    </xsl:template>

  	<xsl:template match="project/architecture-violations">
      	<xsl:choose>
	    	<xsl:when test="@violating-type-relations > 0">
	    		<h3 class="colorRed">Architecture violations (<xsl:value-of select="@number"/> / <xsl:value-of select="@violating-type-relations"/> type relations of <xsl:value-of select="@type-relations"/> / <xsl:value-of select="@percentage-of-violating-type-relations"/>%)</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Architecture violations (0 / 0 type relations of <xsl:value-of select="@type-relations"/>)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="@violating-type-relations > 0">
	        <table class="bodyTable">
	        	<colgroup>
		        	<col width="180"/>
		        	<col/>
		        	<col/>
		        	<col/>
	        	</colgroup>
	            <tr>
	                <th>Element type</th>
	                <th>From element</th>
	                <th>To element</th>
	                <th>Type relations</th>
	            </tr>
	            <xsl:for-each select="violation">
	            	<xsl:sort select="@type-relations" order="descending"/>
	                <tr class="a">
	                    <td><strong><xsl:value-of select="@type"/></strong></td>
	                    <td><strong><xsl:value-of select="@from"/></strong></td>
	                    <td><strong><xsl:value-of select="@to"/></strong></td>
	                    <td><strong><xsl:value-of select="@type-relations"/></strong></td>
	                </tr>
	                <xsl:apply-templates/>
	            </xsl:for-each>
	        </table>
		</xsl:if>
    </xsl:template>

    <xsl:template match="dependency">
        <tr class="a">
            <td align="right"><xsl:value-of select="@from-type"/></td>
            <td><xsl:value-of select="@from"/></td>
            <td><xsl:value-of select="@to"/></td>
            <td></td>
        </tr>
    </xsl:template>

    <xsl:template match="project/cyclic-elements">
      	<xsl:choose>
	    	<xsl:when test="@warnings > 0">
	    		<h3 class="colorRed">Cyclic elements down to '<xsl:value-of select="@analysis-depth"/>' level (<xsl:value-of select="@warnings"/>)</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Cyclic elements down to <xsl:value-of select="@analysis-depth"/> level (0)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
		<xsl:if test="@warnings > 0">
	        <table class="bodyTable">
	        	<colgroup>
	        		<col width="180"/>
	        		<col/>
	        	</colgroup>
	            <tr>
	                <th>Element type</th>
	                <th>Element</th>
	            </tr>
	            <xsl:for-each select="element">
	                <tr class="a">
	                    <td><xsl:value-of select="@type"/></td>
	                    <td><xsl:value-of select="@name"/></td>
	                </tr>
	            </xsl:for-each>
	        </table>
        </xsl:if>
	</xsl:template>

    <xsl:template match="project/work-items">
      	<xsl:choose>
	    	<xsl:when test="@number > 0">
	    		<h3 class="colorRed">Work items (<xsl:value-of select="@number"/>)</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Work items (0)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
        <table class="bodyTable">
        	<colgroup>
        		<col/>
        		<col/>
        		<col/>
        		<col/>
        		<col/>
        		<col/>
        	</colgroup>
            <tr>
                <th>Type</th>
                <th>Description</th>
                <th>Date</th>
                <th>Priority</th>
                <th>Assigned to</th>
                <th>Comment</th>
            </tr>
            <xsl:apply-templates/>
 		</table>
	</xsl:template>
	
    <xsl:template match="item">
        <tr class="a">
            <td><xsl:value-of select="@type"/></td>
            <td><xsl:value-of select="@description"/></td>
            <td><xsl:value-of select="@date"/></td>
            <td><xsl:value-of select="@priority"/></td>
            <td><xsl:value-of select="@assigned-to"/></td>
            <td><xsl:value-of select="@comment"/></td>
        </tr>
    </xsl:template>

    <xsl:template match="project/assignment-report">
      	<xsl:choose>
	    	<xsl:when test="@warnings > 0">
	    		<h3 class="colorRed">Assignment report (<xsl:value-of select="@warnings"/> warning(s))</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Assignment report (0 warnings)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
        <table class="bodyTable">
        	<colgroup>
        		<col width="350"/>
        		<col/>
        	</colgroup>
            <tr>
                <th colspan="2">Package matched by multiple subsystems (<xsl:value-of select="package-to-subsystem/@warnings"/> warning(s))</th>
            </tr>
            <xsl:for-each select="package-to-subsystem/package-matched-by-multiple-subsystems">
                <xsl:sort select="@name"/>
                <tr class="a">
                    <td><xsl:value-of select="@name"/></td>
                    <td>
                        <table class="bodyTable">
                        <xsl:apply-templates>
                            <xsl:sort select="@name"/>
                        </xsl:apply-templates>
                        </table>
                    </td>
                </tr>
            </xsl:for-each>
        </table>
        <table class="bodyTable">
          	<colgroup>
				<col/>
			</colgroup>
            <tr>
                <th>Named subsystem interfaces containing same types (<xsl:value-of select="type-to-named-subsystem-interface/@warnings"/> warning(s))</th>
            </tr>
            <xsl:for-each select="type-to-named-subsystem-interface/identical-named-subsystem-interfaces">
                <xsl:sort select="named-subsystem-interface/@name"/>
                <tr class="a">
                    <td><xsl:value-of select="named-subsystem-interface[1]/@name"/> = <xsl:value-of select="named-subsystem-interface[2]/@name"/></td>
                 </tr>
            </xsl:for-each>
        </table>
    </xsl:template>

    <xsl:template match="subsystem">
        <tr>
            <td><xsl:value-of select="@name"></xsl:value-of></td>
        </tr>
    </xsl:template>

    <xsl:template match="project/element-warnings">
      	<xsl:choose>
	    	<xsl:when test="@warnings > 0">
	    		<h3 class="colorRed">Element warnings (<xsl:value-of select="@warnings"/>)</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Element warnings (0)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
        <xsl:apply-templates>
            <xsl:sort select="@name"/>
        </xsl:apply-templates>
    </xsl:template>

    <xsl:template match="warning">
        <table class="bodyTable">
        	<colgroup>
				<col width="180"/>
				<col/>
				<col width="400"/>
			</colgroup>
            <xsl:choose>
                <xsl:when test="@type='warning-marker'">
                    <tr>
                        <th colspan="3"><xsl:value-of select="@name"/> - <xsl:value-of select="@description"/> (<xsl:value-of select="@warnings"/>)</th>
                    </tr>
                    <xsl:for-each select="warning-element">
                        <xsl:sort select="@type" />
                        <xsl:sort select="@name" />
                        <tr class="a">
                          <td><xsl:value-of select="@type"/></td>
                          <td colspan="2"><xsl:value-of select="@name"/></td>
                        </tr>
                    </xsl:for-each>
                </xsl:when>
                <xsl:otherwise>
                    <tr>
                        <th colspan="2"><xsl:value-of select="@name"/> - <xsl:value-of select="@description"/> (<xsl:value-of select="@warnings"/>)</th>
                        <th align="right">Value<xsl:if test="@info"> (<xsl:value-of select="@info"/>)</xsl:if></th>
                    </tr>
                    <xsl:for-each select="warning-element">
                        <xsl:sort select="@type" />
                        <xsl:sort data-type="number" select="@value" order="descending" />
                        <tr class="a">
                          <td><xsl:value-of select="@type"/></td>
                          <td><xsl:value-of select="@name"/></td>
                          <td><xsl:value-of select="@value"/></td>
                        </tr>
                    </xsl:for-each>
                </xsl:otherwise>
            </xsl:choose>
        </table>
    </xsl:template>

    <xsl:template match="project/exclusion-report">
    	<xsl:choose>
	    	<xsl:when test="@warnings > 0">
	    		<h3 class="colorRed">Exclusion report (<xsl:value-of select="@warnings"/> warning(s))</h3>
	    	</xsl:when>
	    	<xsl:otherwise>
	    		<h3>Exclusion report (0 warnings)</h3>
	    	</xsl:otherwise>
		</xsl:choose>
    	<table class="bodyTable">
    	    <tr>
                <th>Excluded packages from direct input (<xsl:value-of select="excluded-packages-from-direct-input/@number"/>)</th>
             </tr>
        	<xsl:for-each select="excluded-packages-from-direct-input/element">
            	<tr class="a">
                	<td><xsl:value-of select="@name"/></td>
                </tr>
        	</xsl:for-each>
        </table>
       	<table class="bodyTable">
    	    <tr>
                <th>Excluded types from direct input (<xsl:value-of select="excluded-types-from-direct-input/@number"/>)</th>
            </tr>
            <xsl:for-each select="excluded-types-from-direct-input/element">
                <tr class="a">
                    <td><xsl:value-of select="@name"/></td>
                </tr>
            </xsl:for-each>
        </table>
        <table class="bodyTable">
    	    <tr>
                <th>Ignored dependencies to internal types (<xsl:value-of select="ignored-dependencies-to-internal-types/@warnings"/> warning(s))</th>
            </tr>
            <xsl:for-each select="ignored-dependencies-to-internal-types/element">
                <tr class="a">
                    <td><xsl:value-of select="@name"/></td>
                </tr>
            </xsl:for-each>
        </table>
        <table class="bodyTable">
    	    <tr>
                <th>Ignored dependencies to external types (<xsl:value-of select="ignored-dependencies-to-external-types/@number"/>)</th>
            </tr>
            <xsl:for-each select="ignored-dependencies-to-external-types/element">
                <tr class="a">
                    <td><xsl:value-of select="@name"/></td>
                </tr>
            </xsl:for-each>
        </table>
	</xsl:template>
</xsl:stylesheet>
